===============
Py7zr ChangeLog
===============

All notable changes to this project will be documented in this file.

`Unreleased`_
=============

Added
-----

Changed
-------

Fixed
-----

Deprecated
----------

Removed
-------

Security
--------

`v0.0.5`_
=========

* Change decode API to IOBase.readinto(b)

`v0.0.4`_
=========

* Change directory structure.

`v0.0.3`_
=========

* Change API to buffer protocol.

`v0.0.2`_
=========

* Release automation and support manylinux binary.

v0.0.1
======

* First release.


.. History links
.. _Unreleased: https://github.com/miurahr/py7zr/compare/v0.0.5...HEAD
.. _v0.0.5: https://github.com/miurahr/py7zr/compare/v0.0.4...v0.0.5
.. _v0.0.4: https://github.com/miurahr/py7zr/compare/v0.0.3...v0.0.4
.. _v0.0.3: https://github.com/miurahr/py7zr/compare/v0.0.2...v0.0.3
.. _v0.0.2: https://github.com/miurahr/py7zr/compare/v0.0.1...v0.0.2
